# CryoVIT: Efficient Segmentation of Cryo-electron Tomograms with Vision Foundation Models

## Installation Instructions

CryoVIT uses Mamba to manage python packages and dependencies and can be downloaded [here](https://github.com/conda-forge/miniforge). You should also be able to use Conda instead of Mamba but setting up the environment may take an unreasonably long time.

1. Clone the CryoVIT github repository: `git clone https://github.com/sanketx/CryoVIT.git`
2. Setup the mamba environment: `mamba env create -f CryoVIT/env.yml`
3. Activate the mamba environment: `mamba activate cryovit_env`
